@@ -1,14 +1,15 @@
 __author__ = 'fcanas'
 
 import unittest
+
 from IzVerifier.izverifier import IzVerifier
-from IzVerifier.izspecs.verifiers.dependencies import test_verify_all_dependencies
-from IzVerifier.izspecs.izproperties import *
 
 
 path1 = 'data/sample_installer_iz5/izpack/'
 path2 = 'data/sample_installer_iz5/resources/'
 source_path2 = 'data/sample_code_base'
+pom = 'data/sample_installer_iz5/pom.xml'
+
 
 
 class TestDependencies(unittest.TestCase):
@@ -21,6 +22,7 @@ class TestDependencies(unittest.TestCase):
             'specs_path': path1,
             'sources': [source_path2],
             'resources_path': path2,
+            'pom': pom,
             'specs': ['conditions', 'strings', 'variables']
         }
         self.izv = IzVerifier(args)
