@@ -9,40 +9,51 @@ from IzVerifier.izverifier import IzVerifier
 from IzVerifier.izspecs.izproperties import *
 
 
-path1 = '' # path to install.xml
-path2 = '' # path to install.xml
-source_paths = [] # paths to code bases
+path1 = '' # path to specs
+path2 = '' # path to resources
+path3 = '' # path to pom
+source_paths = [''] # paths to code bases
 class TestProduct(unittest.TestCase):
     """
-    Basic testing of seeker class.
+    This is a template class used to test the verifier on real izpack projects.
     """
 
     args = {
             'specs_path': path1,
             'sources': source_paths,
             'resources_path': path2,
+            'pom': path3,
             'specs': ['conditions', 'strings', 'variables']
         }
 
     def setUp(self):
+        #self.loadInstaller(self.args)
         pass
 
-    def verifyInstaller(self, args):
+
+
+    def loadInstaller(self, args):
         """
         Runs the verifications on some installer product.
         """
 
         self.verifier = IzVerifier(args)
         self.seeker = Seeker(self.verifier.paths)
-        langpacks = self.verifier.paths.get_langpacks()
-        langpack = langpacks[0]
         self.conditions = IzConditions(self.verifier.paths.get_path('conditions'))
         self.variables = IzVariables(self.verifier.paths.get_path('variables'))
-        self.strings = IzStrings(langpack[1])
+        langpack = self.verifier.paths.get_langpack_path()
+        self.strings = IzStrings(langpack)
+
+    def verifyInstaller(self):
+        """
+        Run verification tests.
+        """
+        self.verifier.verify_all(verbosity=1)
 
     def test_verifyInstaller(self):
+        #self.verifyInstaller()
         pass
-        #self.verifyInstaller(self.args)
+
 
 
 
